documentationtools.ReSTParagraph
================================

.. abjad-lineage:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph

.. autoclass:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.rest_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.text
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.wrap
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__getstate__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__setstate__
   :noindex:
